| ft_apply_md | R Documentation |
Takes a flextable object and renders any markdown in the specified part.
ft_apply_md(ft, obnd = NULL, part = "body", prows = NULL, pcols = NULL)
ft |
Flextable object. |
obnd |
Optional onbrand object used to format markdown. The default |
part |
Part of the table can be one of |
prows |
Optional rows of the part to process, ignored when |
pcols |
Optional columns of the part to process, ignored when |
flextable with markdown applied
library(onbrand)
library(flextable)
df = data.frame(
A = c("e^x^", "text"),
B = c("sin(x~y~)", "**<ff:symbol>S</ff>**~x~"))
ft = flextable(df) |>
delete_part(part="header") |>
add_header(values =
list(A= "*Italics*",
B= "**Bold**") ) |>
theme_vanilla() |>
ft_apply_md(part="all")
ft
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.