ft_apply_md: Render Markdown in flextable Object
Description
Takes a flextable object and renders any markdown in the
specified part.
Usage
ft_apply_md(ft, obnd = NULL, part = "body")
Value
flextable with markdown applied
Arguments
- ft
Flextable object.
- obnd
Optional onbrand object used to format markdown. The default NULL value will use default formatting.
- part
Part of the table can be one of "all", "body" (default), "header", or "footer"